#ifndef NT2_INCLUDE_FUNCTIONS_IF_ELSE_ALLBITS_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_IF_ELSE_ALLBITS_HPP_INCLUDED

#include <nt2/boolean/include/functions/if_else_allbits.hpp>

#endif
